@@ -68,12 +68,17 @@ test_that("baseline works", {
 
   expect_equal(
     multi_color("one fine day", type = "string"),
-    "\033[38;5;196mon\033[39m\033[38;5;214me \033[39m\033[38;5;226mfi\033[39m\033[38;5;46mne\033[39m\033[38;5;21m d\033[39m\033[38;5;129may\033[39m"
+    "\033[38;5;196mon\033[39m\033[38;5;214me \033[39m\033[38;5;226mfi\033[39m\033[38;5;46mne\033[39m\033[38;5;21m d\033[39m\033[38;5;129may\033[39m\033[39m"
   )
 
   expect_equal(
     multi_color("doowap \n do do doooowap \n digga dig dig da doooo wap \n do do dooooooo", type = "string"),
-    "\033[38;5;196mdoowa\033[39m\033[38;5;214mp \033[39m\n\033[38;5;196m do d\033[39m\033[38;5;214mo doo\033[39m\033[38;5;226moowa\033[39m\033[38;5;46mp \033[39m\n\033[38;5;196m digg\033[39m\033[38;5;214ma dig\033[39m\033[38;5;226m dig\033[39m\033[38;5;46m da d\033[39m\033[38;5;21moooo\033[39m\033[38;5;129m wap \033[39m\n\033[38;5;196m do d\033[39m\033[38;5;214mo doo\033[39m\033[38;5;226moooo\033[39m\033[38;5;46mo\n"
+    "\033[38;5;196mdoowa\033[39m\033[38;5;214mp \033[39m\033[39m\n\033[38;5;196m do d\033[39m\033[38;5;214mo doo\033[39m\033[38;5;226moowa\033[39m\033[38;5;46mp \033[39m\033[39m\n\033[38;5;196m digg\033[39m\033[38;5;214ma dig\033[39m\033[38;5;226m dig\033[39m\033[38;5;46m da d\033[39m\033[38;5;21moooo\033[39m\033[38;5;129m wap \033[39m\033[39m\n\033[38;5;196m do d\033[39m\033[38;5;214mo doo\033[39m\033[38;5;226moooo\033[39m\033[38;5;46mo\033[39m\n"
+  )
+
+  expect_equal(
+    multi_color("Why should Caesar get to stomp around like a giant, while the rest of us try not to get smushed under his big feet? What's so great about Caesar? Brutus is just as cute as Caesar. Brutus is just as smart as Caesar. People totally like Brutus just as much as they like Caesar.", type = "rmd"),
+    "<span style='color: #FF0000;'>Why should Caesar get to stomp around like a g</span><span style='color: #FFAF00;'>iant, while the rest of us try not to get smus</span><span style='color: #FFFF00;'>hed under his big feet? What's so great about </span><span style='color: #00FF00;'>Caesar? Brutus is just as cute as Caesar. Bru</span><span style='color: #0000FF;'>tus is just as smart as Caesar. People totally</span><span style='color: #AF00FF;'> like Brutus just as much as they like Caesar.</span>"
   )
 })
 
@@ -108,15 +113,13 @@ test_that("colors(), including grays, rainbow, and rbg work", {
     )
   )
 
-
-
   # Multiple of the same colors
   expect_equal(
     multi_color("asdfjkl;asdfjk;",
       colors = c("rainbow", "purple", "purple", "rainbow"),
       type = "string"
     ),
-    "\033[38;5;196mas\033[39m\033[38;5;214md\033[38;5;226mf\033[38;5;46mj\033[38;5;21mk\033[38;5;129ml\033[38;5;129m;\033[38;5;129ma\033[38;5;196ms\033[38;5;214md\033[38;5;226mf\033[38;5;46mj\033[38;5;21mk\033[38;5;129m;"
+    "\033[38;5;196mas\033[39m\033[38;5;214md\033[38;5;226mf\033[38;5;46mj\033[38;5;21mk\033[38;5;129ml\033[38;5;129m;\033[38;5;129ma\033[38;5;196ms\033[38;5;214md\033[38;5;226mf\033[38;5;46mj\033[38;5;21mk\033[38;5;129m;\033[39m"
   )
 })
 
@@ -147,7 +150,9 @@ test_that("warnings don't get truncated", {
       suppressWarnings(multi_color(
         txt = cowsay::animals[["yoda"]],
         type = "warning",
-        colors = c("rainbow", "rainbow")
+        colors = c("rainbow", "rainbow"),
+        recycle_chars = TRUE,
+        direction = "horizontal"
       ))
     )
   )
@@ -168,6 +173,7 @@ test_that("warnings don't get truncated", {
     suppressMessages(
       suppressWarnings(multi_color(
         txt = long_text,
+        recycle_chars = TRUE,
         type = "warning"
       ))
     )
@@ -227,6 +233,14 @@ test_that("utils", {
 test_that("crawl works", {
   expect_output(crawl())
 
+  expect_error(
+    crawl(pause = -1) # invalid time between chars
+  )
+
+  expect_error(
+    crawl(runif) # txt has to be character
+  )
+
   skip_if_not(use_color())
   expect_error(
     crawl(colors = c(
@@ -234,15 +248,4 @@ test_that("crawl works", {
       "green"
     )) # bad colors
   )
-
-  expect_error(
-    crawl(pause = -1) # invalid time between chars
-  )
-
-  expect_error(
-    crawl(colors = c(
-      "seafoamgreen",
-      "green"
-    )) # bad colors
-  )
 })
